@@ -188,7 +188,7 @@ atspi_accessible_init (AtspiAccessible *accessible)
 
   accessible->priv = atspi_accessible_get_instance_private (accessible);
 
-  accessible->children = g_ptr_array_new_with_free_func (atspi_accessible_unref);
+  accessible->children = g_ptr_array_new_with_free_func ((GDestroyNotify) atspi_accessible_unref);
 }
 
 static void
