@@ -7,19 +7,19 @@
  * Copyright 2010, 2011 Novell, Inc.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "atspi-private.h"
@@ -962,47 +962,6 @@ atspi_text_scroll_substring_to_point (AtspiText *obj,
   return retval;
 }
 
-/**
- * atspi_text_notify_reading_position:
- * @obj: the #AtspiText object being read.
- * @startOffset: the offset of the text currently being read.
- * @endOffset: the offset of the end of the text currently being read.
- *
- * Notifies interested listeners of the specific text that the screen
- * reader is currently reading. This allows a magnifier to synchronize with
- * the screen reader and highlight the text that is currently being read.
- */
-void
-atspi_text_notify_reading_position (AtspiText *obj,
-                                    gint startOffset,
-                                    gint endOffset)
-{
-  DBusMessage *signal;
-  AtspiAccessible *accessible;
-  DBusMessageIter iter, iter_struct;
-
-  g_return_if_fail (obj != NULL);
-
-  accessible = ATSPI_ACCESSIBLE(obj);
-
-  if (!_atspi_prepare_screen_reader_interface ())
-    return;
-
-  signal = dbus_message_new_signal (ATSPI_DBUS_PATH_SCREEN_READER,
-                                    ATSPI_DBUS_INTERFACE_SCREEN_READER,
-                                    "ReadingPosition");
-  dbus_message_iter_init_append (signal, &iter);
-  dbus_message_iter_open_container (&iter, DBUS_TYPE_STRUCT, NULL,
-                                    &iter_struct);
-  dbus_message_iter_append_basic (&iter_struct, DBUS_TYPE_STRING, &accessible->parent.app->bus_name);
-  dbus_message_iter_append_basic (&iter_struct, DBUS_TYPE_OBJECT_PATH, &accessible->parent.path);
-  dbus_message_iter_close_container (&iter, &iter_struct);
-  dbus_message_iter_append_basic (&iter, DBUS_TYPE_INT32, &startOffset);
-  dbus_message_iter_append_basic (&iter, DBUS_TYPE_INT32, &endOffset);
-  dbus_connection_send (_atspi_bus (), signal, NULL);
-  dbus_message_unref (signal);
-}
-
 static void
 atspi_text_base_init (AtspiText *klass)
 {
