@@ -69,6 +69,7 @@ typedef struct {
   int pipefd[2];
   int listenfd;
   char *a11y_launch_error_message;
+  GDBusProxy *sm_proxy;
 } A11yBusLauncher;
 
 static A11yBusLauncher *_global_app = NULL;
@@ -139,28 +140,61 @@ client_proxy_ready_cb (GObject      *source_object,
                     G_CALLBACK (g_signal_cb), app);
 }
 
+static void
+client_registered (GObject *source,
+                   GAsyncResult *result,
+                   gpointer user_data)
+{
+  A11yBusLauncher *app = user_data;
+  GError *error = NULL;
+  GVariant *variant;
+  gchar *object_path;
+  GDBusProxyFlags flags;
+
+  variant = g_dbus_proxy_call_finish (app->sm_proxy, result, &error);
+  if (!variant)
+    {
+      if (error != NULL)
+        {
+          g_warning ("Failed to register client: %s", error->message);
+          g_error_free (error);
+        }
+    }
+  else
+    {
+      g_variant_get (variant, "(o)", &object_path);
+      g_variant_unref (variant);
+
+      flags = G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES;
+      g_dbus_proxy_new_for_bus (G_BUS_TYPE_SESSION, flags, NULL,
+                                "org.gnome.SessionManager", object_path,
+                                "org.gnome.SessionManager.ClientPrivate",
+                                NULL, client_proxy_ready_cb, app);
+
+      g_free (object_path);
+    }
+  g_clear_object (&app->sm_proxy);
+}
+
 static void
 register_client (A11yBusLauncher *app)
 {
   GDBusProxyFlags flags;
-  GDBusProxy *sm_proxy;
   GError *error;
   const gchar *app_id;
   const gchar *autostart_id;
   gchar *client_startup_id;
   GVariant *parameters;
-  GVariant *variant;
-  gchar *object_path;
 
   flags = G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES |
           G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS;
 
   error = NULL;
-  sm_proxy = g_dbus_proxy_new_sync (app->session_bus, flags, NULL,
-                                    "org.gnome.SessionManager",
-                                    "/org/gnome/SessionManager",
-                                    "org.gnome.SessionManager",
-                                    NULL, &error);
+  app->sm_proxy = g_dbus_proxy_new_sync (app->session_bus, flags, NULL,
+                                         "org.gnome.SessionManager",
+                                         "/org/gnome/SessionManager",
+                                         "org.gnome.SessionManager",
+                                         NULL, &error);
 
   if (error != NULL)
     {
@@ -187,31 +221,11 @@ register_client (A11yBusLauncher *app)
   g_free (client_startup_id);
 
   error = NULL;
-  variant = g_dbus_proxy_call_sync (sm_proxy,
-                                    "RegisterClient", parameters,
-                                    G_DBUS_CALL_FLAGS_NONE,
-                                    -1, NULL, &error);
+  g_dbus_proxy_call (app->sm_proxy,
+                     "RegisterClient", parameters,
+                     G_DBUS_CALL_FLAGS_NONE,
+                     G_MAXINT, NULL, client_registered, app);
 
-  g_object_unref (sm_proxy);
-
-  if (error != NULL)
-    {
-      g_warning ("Failed to register client: %s", error->message);
-      g_error_free (error);
-
-      return;
-    }
-
-  g_variant_get (variant, "(o)", &object_path);
-  g_variant_unref (variant);
-
-  flags = G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES;
-  g_dbus_proxy_new_for_bus (G_BUS_TYPE_SESSION, flags, NULL,
-                            "org.gnome.SessionManager", object_path,
-                            "org.gnome.SessionManager.ClientPrivate",
-                            NULL, client_proxy_ready_cb, app);
-
-  g_free (object_path);
 }
 
 static void
